# eric7.Plugins.VcsPlugins.vcsMercurial.LargefilesExtension.LfRevisionsInputDialog

Module implementing a dialog to enter a series of revisions.

### Global Attributes

None

### Classes

LfRevisionsInputDialog | Class implementing a dialog to enter a series of revisions.

### Functions

None

## LfRevisionsInputDialog

Class implementing a dialog to enter a series of revisions.

### Derived from

QDialog, Ui_LfRevisionsInputDialog

### Class Attributes

None

### Class Methods

None

### Methods

LfRevisionsInputDialog | Constructor
getRevisions | Public method to retrieve the entered revisions.
on_revisionsEdit_textChanged | Private slot handling a change of revisions.

### Static Methods

None

#### LfRevisionsInputDialog (Constructor)

LfRevisionsInputDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### LfRevisionsInputDialog.getRevisions

getRevisions()

Public method to retrieve the entered revisions.

Return:
  list of revisions

Return Type:
  list of str

#### LfRevisionsInputDialog.on_revisionsEdit_textChanged

on_revisionsEdit_textChanged()

Private slot handling a change of revisions.

Up